# TieredStore

TieredStore is a description of the tiered store
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**levels** | [**list[Level]**](Level.md) | configurations for multiple tiers | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


